summaryrefslogtreecommitdiff
path: root/src/scrcmd.c
diff options
context:
space:
mode:
authorDeokishisu <6993375+Deokishisu@users.noreply.github.com>2021-02-15 14:54:35 -0500
committerDeokishisu <6993375+Deokishisu@users.noreply.github.com>2021-02-15 14:54:35 -0500
commit7b2bf8c7e2249f66a04eabdbaeb2a8018855955f (patch)
treefd9c56262c4ef44569f313e5e067523a6a3546bf /src/scrcmd.c
parentb89c3e901e1de2f3513d74fa548373d82d3f26d0 (diff)
Rename obedient/fatefulEncounter to eventLegal
Per discussion on pret, `obedient`/`fatefulEncounter` has been renamed to `eventLegal`, and all related functions and constants have been modified with this in mind. Additionally, fixed some whitespace alignment issues in `script_cmd_table.h`, `pokemon.h`, and `tv.c` from the last commit.
Diffstat (limited to 'src/scrcmd.c')
-rw-r--r--src/scrcmd.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/scrcmd.c b/src/scrcmd.c
index 0b9e3d445..7caaa194b 100644
--- a/src/scrcmd.c
+++ b/src/scrcmd.c
@@ -2207,21 +2207,21 @@ bool8 ScrCmd_lockfortrainer(struct ScriptContext *ctx)
}
}
-// This command will set a Pokémon's Fateful Encounter bit; there is no similar command to clear it.
-bool8 ScrCmd_setmonfatefulencounter(struct ScriptContext *ctx)
+// This command will set a Pokémon's eventLegal bit; there is no similar command to clear it.
+bool8 ScrCmd_setmoneventlegal(struct ScriptContext *ctx)
{
- bool8 isFatefulEncounter = TRUE;
+ bool8 isEventLegal = TRUE;
u16 partyIndex = VarGet(ScriptReadHalfword(ctx));
- SetMonData(&gPlayerParty[partyIndex], MON_DATA_FATEFUL_ENCOUNTER, &isFatefulEncounter);
+ SetMonData(&gPlayerParty[partyIndex], MON_DATA_EVENT_LEGAL, &isEventLegal);
return FALSE;
}
-bool8 ScrCmd_checkmonfatefulencounter(struct ScriptContext *ctx)
+bool8 ScrCmd_checkmoneventlegal(struct ScriptContext *ctx)
{
u16 partyIndex = VarGet(ScriptReadHalfword(ctx));
- gSpecialVar_Result = GetMonData(&gPlayerParty[partyIndex], MON_DATA_FATEFUL_ENCOUNTER, NULL);
+ gSpecialVar_Result = GetMonData(&gPlayerParty[partyIndex], MON_DATA_EVENT_LEGAL, NULL);
return FALSE;
}